@@ -1,6 +1,5 @@
 package CGI::Application::Plugin::RunmodeParseKeyword;
-$CGI::Application::Plugin::RunmodeParseKeyword::VERSION = '0.15_01'; # TRIAL
-$CGI::Application::Plugin::RunmodeParseKeyword::VERSION = '0.1501';
+$CGI::Application::Plugin::RunmodeParseKeyword::VERSION = '0.11';
 use warnings;
 use strict;
 
@@ -10,31 +9,24 @@ CGI::Application::Plugin::RunmodeParseKeyword - Declare runmodes using Parse::Ke
 
 =cut
 
+use base 'Exporter';
 our @EXPORT = qw(runmode errormode startmode);
 use Carp qw(croak);
 use Sub::Name 'subname';
-use Data::Dumper;
 use Parse::Keyword {};
 
-$Carp::Internal{ (__PACKAGE__) }++;
-
 sub import {
     my $caller = caller;
     my $class = shift;
     my %args = @_;
-    my $into = delete $args{into} || $caller;
     my $inv = delete $args{invocant} || '$self';
 
     Parse::Keyword->import( { runmode   => sub { my ($kw) = @_; parse_mode($kw, $inv); } } );
     Parse::Keyword->import( { errormode => sub { my ($kw) = @_; parse_mode($kw, $inv); } } );
     Parse::Keyword->import( { startmode => sub { my ($kw) = @_; parse_mode($kw, $inv); } } );
 
-    for my $e(@EXPORT) {
-        my $fn = $into . '::' . $e;
-        no strict 'refs';
-        *$fn = \&$e;
-        *$fn if 0;
-    }
+    local $Exporter::ExportLevel = 1;
+    $class->SUPER::import(@EXPORT);
 }
 
 sub runmode { @_ ? $_[0] : () }
@@ -104,7 +96,7 @@ sub parse_mode {
     my $name = parse_name();
     my $sig  = parse_signature($invocant);
     my $attr = parse_attributes();
-    my $body = parse_body($sig) or ($@ and die);
+    my $body = parse_body($sig);
 
     if (defined $name) {
         my $full_name = join('::', compiling_package, $name);
@@ -156,8 +148,7 @@ sub parse_signature {
     my ($invocant_name) = @_;
     lex_read_space;
 
-    my @vars = ({ index => 0, name => $invocant_name });
-    return \@vars unless lex_peek eq '(';
+    return unless lex_peek eq '(';
 
     my @attr = ();
 
@@ -166,13 +157,14 @@ sub parse_signature {
 
     if (lex_peek eq ')') {
         lex_read;
-        return \@vars;
+        return;
     }
 
     my $seen_slurpy;
+    my @vars = ({ index => 0, name => $invocant_name });
     while ((my $sigil = lex_peek) ne ')') {
         my $var = {};
-        die "syntax error: expected ')' but found '$sigil'"
+        die "syntax error"
             unless $sigil eq '$' || $sigil eq '@' || $sigil eq '%';
         die "Can't declare parameters after a slurpy parameter"
             if $seen_slurpy;
@@ -203,9 +195,8 @@ sub parse_signature {
 
         push @vars, $var;
 
-        my $c = lex_peek;
-        die "syntax error: expected ')' or ',' but found '$c'"
-            unless $c eq ')' || $c eq ',';
+        die "syntax error"
+            unless lex_peek eq ')' || lex_peek eq ',';
 
         if (lex_peek eq ',') {
             lex_read;
@@ -290,9 +281,7 @@ sub parse_body {
 
     lex_read_space;
 
-    my $c = lex_peek;
-    croak "syntax error: expected start of block '{' but found '$c'" unless $c eq '{';
-    {
+    if (lex_peek eq '{') {
         local $CAPRPK::{'DEFAULTS::'};
         if ($sigs) {
             lex_read;
@@ -308,17 +297,16 @@ sub parse_body {
             $preamble .= 'my (' . join(', ', @names) . ') = @_;';
 
             for my $name (@names) {
-                my $p;
                 my $s = substr($name,0,1);
                 my $n = substr($name,1);
                 if ($s eq '$') {
-                    $p = $inv->{name} . '->param("' . $n . '")';
+                    my $p = $inv->{name} . '->param("' . $n . '")';
                     $preamble .= $name . ' = ' . $p . ' unless ' . ( $s eq '$' ? 'defined ' : 'scalar ') . $name . ';';
                 }
-                $p = $inv->{name} . '->query->' . ($s eq '@' ? 'multi_param' : 'param') . '("' . $n . '")';
+                my $p = $inv->{name} . '->query->' . ($s eq '@' ? 'multi_param' : 'param') . '("' . $n . '")';
                 $preamble .= $name . ' = ' . $p . ' unless ' . ( $s eq '$' ? 'defined ' : 'scalar ') . $name . ';';
                 if ($s eq '@') {
-                    $p = $inv->{name} . '->query->' . ($s eq '@' ? 'multi_param' : 'param') . '("' . $n . '[]")';
+                    my $p = $inv->{name} . '->query->' . ($s eq '@' ? 'multi_param' : 'param') . '("' . $n . '[]")';
                     $preamble .= $name . ' = ' . $p . ' unless ' . ( $s eq '$' ? 'defined ' : 'scalar ') . $name . ';';
                 }
             }
@@ -341,6 +329,9 @@ sub parse_body {
         }
         $body = parse_block;
     }
+    else {
+        die "syntax error";
+    }
     return $body;
 }
 
@@ -505,7 +496,7 @@ You tried to install another startmode. Placeholders are filled with
 =head1 BUGS
 
 Please report any bugs or feature requests to
-C<bug-cgi-application-plugin-runmodeparsekeyword at rt.cpan.org>, or through the web
+C<bug-cgi-application-plugin-runmodedeclare at rt.cpan.org>, or through the web
 interface at
 L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CGI-Application-Plugin-RunmodeParseKeyword>.
 I will be notified, and then you'll automatically be notified of progress on
